summaryrefslogtreecommitdiff
path: root/board/taeko/fw_config.h
diff options
context:
space:
mode:
Diffstat (limited to 'board/taeko/fw_config.h')
-rw-r--r--board/taeko/fw_config.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/board/taeko/fw_config.h b/board/taeko/fw_config.h
index 6e4eb3ef58..7e59a4308e 100644
--- a/board/taeko/fw_config.h
+++ b/board/taeko/fw_config.h
@@ -3,15 +3,15 @@
* found in the LICENSE file.
*/
-#ifndef __BOARD_BRYA_FW_CONFIG_H_
-#define __BOARD_BRYA_FW_CONFIG_H_
+#ifndef __BOARD_TAEKO_FW_CONFIG_H_
+#define __BOARD_TAEKO_FW_CONFIG_H_
#include <stdint.h>
/****************************************************************************
* CBI FW_CONFIG layout for Brya board.
*
* Source of truth is the project/brya/brya/config.star configuration file.
*/
enum ec_cfg_usb_db_type {
@@ -25,7 +25,7 @@ enum ec_cfg_keyboard_backlight_type {
KEYBOARD_BACKLIGHT_ENABLED = 1
};
-union brya_cbi_fw_config {
+union taeko_cbi_fw_config {
struct {
enum ec_cfg_usb_db_type usb_db : 4;
uint32_t sd_db : 2;
@@ -42,7 +42,7 @@ union brya_cbi_fw_config {
*
* @return the FW_CONFIG for the board.
*/
-union brya_cbi_fw_config get_fw_config(void);
+union taeko_cbi_fw_config get_fw_config(void);
/**
* Get the USB daughter board type from FW_CONFIG.
@@ -51,4 +51,4 @@ union brya_cbi_fw_config get_fw_config(void);
*/
enum ec_cfg_usb_db_type ec_cfg_usb_db_type(void);
-#endif /* __BOARD_BRYA_FW_CONFIG_H_ */
+#endif /* __BOARD_TAEKO_FW_CONFIG_H_ */
@@ -3,15 +3,15 @@
#include <stdint.h>
/****************************************************************************
- * CBI FW_CONFIG layout for Brya board.
+ * CBI FW_CONFIG layout for Taeko board.
*
@@ -3,15 +3,15 @@
*
- * Source of truth is the project/brya/brya/config.star configuration file.
+ * Source of truth is the project/taeko/taeko/config.star configuration file.
*/
enum ec_cfg_usb_db_type {